@@ -2,13 +2,14 @@ package Nephia::View;
 
 use strict;
 use warnings;
-use Nephia::ClassLoader;
+use Module::Load ();
 
 sub new {
     my ( $class, %opts ) = @_;
     $opts{class} ||= 'MicroTemplate';
     my $subclass = join '::', __PACKAGE__, delete $opts{class};
-    Nephia::ClassLoader->load( $subclass );
+
+    Module::Load::load($subclass);
     return $subclass->new( %opts );
 }
 
